@@ -62,6 +62,16 @@ class WebConfig:
         })
 
 
+class Env:
+    config_dir: str
+    user_config_dir: str
+    site_config_dir: str
+    plugin_dir: str
+
+    def __init__(self, data: Dict):
+        utils.copy_value(data, self)
+
+
 class ConfigApi:
     def __init__(self, session: Session):
         self._session: Session = session
@@ -77,3 +87,7 @@ class ConfigApi:
     @property
     def web(self):
         return WebConfig(self._session.get('setting.get_web'), self._session)
+
+    @property
+    def env(self):
+        return Env(self._session.get('setting.get_env'))
