@@ -1,3 +1,4 @@
+from enum import Enum
 from typing import List, Optional, Dict
 
 from moviebotapi import Session
@@ -14,6 +15,12 @@ class MediaLibraryPath:
             utils.copy_value(data, self)
 
 
+class TransferMode(Enum):
+    HardLink = 'link'
+    Copy = 'copy'
+    Move = 'move'
+
+
 class LibraryApi:
     def __init__(self, session: Session):
         self._session: Session = session
@@ -40,3 +47,10 @@ class LibraryApi:
         return self._session.post('library.rename_by_path', {
             'path': path
         })
+
+    def direct_transfer(self, src: str, dst: str, mode: TransferMode):
+        self._session.post('library.direct_transfer', {
+            'src': src,
+            'dst': dst,
+            'mode': mode.value
+        })
